@@ -263,7 +263,11 @@ class DBConnect:
                     find_dict[filter_key] = filter_value
                 elif filter_key == 'id' or filter_key == '_id':
                     find_dict['_id'] = ObjectId(str(filter_value))
+                elif type(filter_value) == list:
+                    # 值为列表，则使用元素匹配逻辑，将数据库中对应字段包含list元素的数据全部赛选出来
+                    find_dict[filter_key] = {"$elemMatch":{"$in": filter_value}}
                 else:
+                    # 查询值模糊匹配的结果
                     if filter_value.strip() != '':
                         find_dict[filter_key] = {'$regex': filter_value}
             # 仅存在日期查询区间参数时，进行额外的创建时间区间查询
