@@ -37,6 +37,9 @@ def set_token_session(app, verify, per_defaults: list, whitelist: list = []):
         for per in per_defaults:
             session[per['session_key']] = verify.permission_verify(
                 per['center_name'], per['permission_name'])
+        if verify.group_list == None:
+            verify.group_list = []
+        session['group_list'] = verify.group_list
 
 
 class VerifyToken:
@@ -45,6 +48,7 @@ class VerifyToken:
         self.debug_permission = debug_permission
         self.proxy_none_response = proxy_none_response  # 代理无权限响应
         self.uid = ''
+        self.group_list = None
         # 认证中心的 Redis 库号码
         self.redis_db_permission = os.environ.get('REDIS_DB_PERMISSION', None)
         self.secret_key = os.environ.get(
@@ -183,6 +187,8 @@ class VerifyToken:
         is_all_data = False
         user = self.user_db.find_docu_by_id(id=self.uid)  # 查询用户对应的角色数据
         role_name_list = user['role_name']  # 用户包含的所有角色名称
+        if self.group_list == None:
+            self.group_list = user['group_name']  # 用户包含的所有组别名称
         # 合并多角色权限
         permission_list = []
         is_all_data_list = []
